You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@echarts.apache.org by sh...@apache.org on 2021/05/08 12:44:32 UTC

[echarts] branch enhance-visual-regression-test updated: test(visual): fix no action will freeze the cli

This is an automated email from the ASF dual-hosted git repository.

shenyi pushed a commit to branch enhance-visual-regression-test
in repository https://gitbox.apache.org/repos/asf/echarts.git


The following commit(s) were added to refs/heads/enhance-visual-regression-test by this push:
     new 2aaed11  test(visual): fix no action will freeze the cli
2aaed11 is described below

commit 2aaed112435c53e150dcfb67af8411ecb374c3fd
Author: pissang <bm...@gmail.com>
AuthorDate: Sat May 8 20:43:16 2021 +0800

    test(visual): fix no action will freeze the cli
---
 test/runTest/cli.js          | 6 +++---
 test/runTest/runtime/main.js | 4 ++--
 2 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/test/runTest/cli.js b/test/runTest/cli.js
index 9c6e88f..1d7f6ce 100644
--- a/test/runTest/cli.js
+++ b/test/runTest/cli.js
@@ -257,10 +257,10 @@ async function runTestPage(browser, testOpt, version, runtimeCode, isExpected) {
             catch (e) {
                 errors.push(e.toString());
             }
+            // We need to use the actions finish signal if there is reload happens in the page.
+            // Because the original __VST_RUN_ACTIONS__ not exists anymore.
+            await waitForActionFinishManually;
         }
-        // We need to use the actions finish signal if there is reload happens in the page.
-        // Because the original __VST_RUN_ACTIONS__ not exists anymore.
-        await waitForActionFinishManually;
     }
     catch(e) {
         console.error(e);
diff --git a/test/runTest/runtime/main.js b/test/runTest/runtime/main.js
index 4a55030..629d53c 100644
--- a/test/runTest/runtime/main.js
+++ b/test/runTest/runtime/main.js
@@ -58,12 +58,12 @@ window.__VST_START__ = function () {
         }, 500);
     }
     else {
         // Screenshot after 2000ms (400ms if 5x speed), wait the animation to be finished
         setTimeout(async () => {
             // Pause timeline until run actions.
             timeline.pause();
             await __VST_FULL_SCREENSHOT__();
-        }, 2000);
+        }, 1000);
     }
 }
 

---------------------------------------------------------------------
@@ -58,12 +58,12 @@ window.__VST_START__ = function () {
     }
     else {
-        // Screenshot after 2000ms (400ms if 5x speed), wait the animation to be finished
+        // Screenshot after 1000ms (200ms if 5x speed), wait the animation to be finished
         setTimeout(async () => {
             // Pause timeline until run actions.
To unsubscribe, e-mail: commits-unsubscribe@echarts.apache.org
For additional commands, e-mail: commits-help@echarts.apache.org